# -*- coding: utf-8 -*-
#
# Cookbook Name:: openfortivpn
# Recipe:: install
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

version = node['openfortivpn']['install']['version']
remotefile = 'https://github.com/adrienverge/openfortivpn'\
             "/archive/#{version}.tar.gz"
localfile = "#{Chef::Config[:file_cache_path]}/openfortivpn-#{version}.tar.gz"

include_recipe 'apt'
include_recipe 'build-essential'
package 'libssl-dev'

directory node['openfortivpn']['install']['build_dir'] do
  recursive true
end

remote_file localfile do
  source remotefile
end

execute 'untar' do
  cwd node['openfortivpn']['install']['build_dir']
  command "tar --strip-components 1 -xzf #{localfile}"
end

execute 'build-openfortivpn' do
  cwd node['openfortivpn']['install']['build_dir']
  command 'aclocal && autoconf && automake --add-missing &&'\
          './configure --prefix=/usr --sysconfdir=/etc &&'\
          'make'
end

execute 'make install' do
  cwd node['openfortivpn']['install']['build_dir']
end
